@@ -6,8 +6,8 @@
 ;; Homepage: https://github.com/tarsius/hl-todo
 ;; Keywords: convenience
 
-;; Package-Version: 3.8.3
-;; Package-Requires: ((emacs "26.1") (compat "30.0.2.0"))
+;; Package-Version: 3.8.5
+;; Package-Requires: ((emacs "26.1") (compat "30.1"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -288,8 +288,7 @@ If COLOR is a face symbol, do not combine, return COLOR instead."
   (if hl-todo-mode
       (font-lock-add-keywords nil hl-todo--keywords t)
     (font-lock-remove-keywords nil hl-todo--keywords))
-  (when font-lock-mode
-    (jit-lock-mode 1)))
+  (font-lock-flush))
 
 ;;;###autoload
 (define-globalized-minor-mode global-hl-todo-mode
